@@ -14,7 +14,11 @@ else:
             from elementtree import ElementTree
         except ImportError:
             raise Exception('ElementTree must be installed')
-
+            
+class Object(object):
+    'A blank object'
+    pass
+                
 class ActiveResourceException(Exception):
     pass
 
@@ -123,11 +127,33 @@ class ActiveResource(object):
         return attrs
     _extract_attrs = classmethod(_extract_attrs)
         
-    def _parse_xml(cls, xml):
-        e = ElementTree.fromstring(xml)
-        return [cls(**cls._extract_attrs(el)) for el in e.findall(cls.Meta.name)]
+    def _parse_xml(cls, el):
+        if isinstance(el, basestring):
+            el = ElementTree.fromstring(el)
+
+        is_list = len(set([e.tag for e in el.getchildren()])) == 1
+
+        if el.attrib.get('type') == 'array' or is_list:
+            obj = [cls._parse_xml(e) for e in el.getchildren()]
+        elif el.getchildren():
+            if el.tag == cls.Meta.name:
+                obj = cls()
+            else:
+                obj = Object()
+            [setattr(obj, e.tag.replace('-', '_'), cls._parse_xml(e)) for e in el.getchildren()]
+            
+            if isinstance(obj, cls):
+                obj.Meta.changed = []
+                
+        elif el.text:
+            obj = el.text
+            if el.attrib.get('type') == 'integer':
+                val = int(obj)
+        elif el.attrib.get('nil') == 'true':
+            obj = None
+        return obj
     _parse_xml = classmethod(_parse_xml)
-        
+    
     def _make_request(cls, obj=None, method='GET', params={}, headers={}):        
         if cls.Meta.auth and not headers.has_key('Authorization'):
             headers['Authorization'] = cls.Meta.auth
